You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [29/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/strategy.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/strategy.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/strategy.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/strategy.apt Tue May 20 11:51:35 2008
@@ -7,7 +7,7 @@
   Another of the Gang Of Four patterns, the strategy pattern as implemented in Tapestry IoC is a kind of late binding.
   
   The idea is that <adapters> for objects are accessed based on the <actual type> of an object.  These adapters supply additional functionality.  The adapters
-  are located using an {{{../apidocs/org/apache/tapestry/util/StrategyRegistry.html}StrategyRegistry}}.
+  are located using an {{{../apidocs/org/apache/tapestry5/util/StrategyRegistry.html}StrategyRegistry}}.
   
   The lookup of adapters is based on an inheritance search; thus providing an adapter for type java.util.Map will match any object that implements the Map interface.
   The inheritance search works its way up the class hierarchy looking for a matching registration. If nothing is found, then all the interfaces directly or indirectly
@@ -17,7 +17,7 @@
   
   As a special case, the value null is search for as if it was an instance of the class void.
     
-  The {{{../apidocs/org/apache/tapestry/ioc/services/StrategyBuilder.html}StrategyBuilder}} service creates a service implementation around a strategy registry.
+  The {{{../apidocs/org/apache/tapestry5/ioc/services/StrategyBuilder.html}StrategyBuilder}} service creates a service implementation around a strategy registry.
   
 +---+
 public interface StrategyBuilder

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/symbols.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/symbols.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/symbols.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/symbols.apt Tue May 20 11:51:35 2008
@@ -11,8 +11,8 @@
   name is segmented with periods.
   
   These symbols are used inside the 
-  {{{../apidocs/org/apache/tapestry/ioc/annoations/Value.html}Value}} and
-  {{{../apidocs/org/apache/tapestry/ioc/annoations/InjectService.html}InjectService}}
+  {{{../apidocs/org/apache/tapestry5/ioc/annoations/Value.html}Value}} and
+  {{{../apidocs/org/apache/tapestry5/ioc/annoations/InjectService.html}InjectService}}
   annotations.
   
   For example:
@@ -34,9 +34,9 @@
 Symbol Resolution
 
   Symbols are resolved by the
-  {{{../apidocs/org/apache/tapestry/ioc/services/SymbolSource.html}SymbolSource}} service.  The SymbolSource
+  {{{../apidocs/org/apache/tapestry5/ioc/services/SymbolSource.html}SymbolSource}} service.  The SymbolSource
   checks against an ordered list of
-  {{{../apidocs/org/apache/tapestry/ioc/services/SymbolProvider.html}SymbolProvider}} objects.
+  {{{../apidocs/org/apache/tapestry5/ioc/services/SymbolProvider.html}SymbolProvider}} objects.
 
   Additional symbol providers may be employed by contributing to the tapestry.ioc.SymbolSource service configuration,
   which is an ordered list of SymbolProviders.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/upgrade.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/upgrade.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/upgrade.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/site/apt/upgrade.apt Tue May 20 11:51:35 2008
@@ -14,11 +14,11 @@
 
 Release 5.0.12
 
-  Several methods of {{{../apidocs/org/apache/tapestry/ioc/services/ClassFabUtils.html}ClassFabUtils}}
+  Several methods of {{{../apidocs/org/apache/tapestry5/ioc/services/ClassFabUtils.html}ClassFabUtils}}
   have been removed.  The new method {{{castReference()}}} is an improved replacement for the removed
   methods. These methods were largely used when decorating services, and the new 
-  {{{../apidocs/org/apache/tapestry/ioc/services/AspectDecorator.html}AspectDecorator}} is even easier.
+  {{{../apidocs/org/apache/tapestry5/ioc/services/AspectDecorator.html}AspectDecorator}} is even easier.
 
   For {{{https://issues.apache.org/jira/browse/TAPESTRY-2421}TAPESTRY-2421}} (compatibility between
-  Tapestry 4 and Tapestry 5), the org.apache.tapestry.ioc.annotations package was renamed
-  to org.apache.tapestry.ioc.annotation.
\ No newline at end of file
+  Tapestry 4 and Tapestry 5), the org.apache.tapestry5.ioc.annotations package was renamed
+  to org.apache.tapestry5.ioc.annotations.
\ No newline at end of file

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/conf/testng.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/conf/testng.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/conf/testng.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/conf/testng.xml Tue May 20 11:51:35 2008
@@ -18,16 +18,16 @@
 <suite name="Tapestry IOC" thread-count="10" annotations="1.5" verbose="2" parallel="tests">
     <test name="Public APIs">
         <packages>
-            <package name="org.apache.tapestry.ioc"/>
-            <package name="org.apache.tapestry.ioc.services"/>
-            <package name="org.apache.tapestry.ioc.util"/>
+            <package name="org.apache.tapestry5.ioc"/>
+            <package name="org.apache.tapestry5.ioc.services"/>
+            <package name="org.apache.tapestry5.ioc.util"/>
         </packages>
     </test>
     <test name="Internals">
         <packages>
-            <package name="org.apache.tapestry.ioc.internal"/>
-            <package name="org.apache.tapestry.ioc.internal.services"/>
-            <package name="org.apache.tapestry.ioc.internal.util"/>
+            <package name="org.apache.tapestry5.ioc.internal"/>
+            <package name="org.apache.tapestry5.ioc.internal.services"/>
+            <package name="org.apache.tapestry5.ioc.internal.util"/>
         </packages>
     </test>
 </suite>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/AutobuildModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/AutobuildModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/AutobuildModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/AutobuildModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class AutobuildModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BarneyModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BarneyModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BarneyModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BarneyModule.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Match;
-import org.apache.tapestry.ioc.annotation.Order;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.annotations.Match;
+import org.apache.tapestry5.ioc.annotations.Order;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 import java.util.ArrayList;
 import java.util.HashMap;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BaseLocatableTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BaseLocatableTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BaseLocatableTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BaseLocatableTest.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import org.testng.annotations.Test;
 
 public class BaseLocatableTest extends IOCTestCase

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BlueMarker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BlueMarker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BlueMarker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/BlueMarker.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,7 +22,7 @@
 import java.lang.annotation.Target;
 
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface BlueMarker

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ConcreteServiceBuilderModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ConcreteServiceBuilderModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ConcreteServiceBuilderModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ConcreteServiceBuilderModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class ConcreteServiceBuilderModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/CountingGreeterImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/CountingGreeterImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/CountingGreeterImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/CountingGreeterImpl.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class CountingGreeterImpl implements Greeter
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DecoratorList.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DecoratorList.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DecoratorList.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DecoratorList.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.util.List;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateFredModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateFredModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateFredModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateFredModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class DuplicateFredModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateServiceTypeModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateServiceTypeModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateServiceTypeModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/DuplicateServiceTypeModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class DuplicateServiceTypeModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/EagerLoadModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/EagerLoadModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/EagerLoadModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/EagerLoadModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.EagerLoad;
+import org.apache.tapestry5.ioc.annotations.EagerLoad;
 
 /**
  * Used to test service eager loading.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FailInConstructorRunnable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FailInConstructorRunnable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FailInConstructorRunnable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FailInConstructorRunnable.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class FailInConstructorRunnable implements Runnable
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FredModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FredModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FredModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/FredModule.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Match;
-import org.apache.tapestry.ioc.annotation.Order;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.annotations.Match;
+import org.apache.tapestry5.ioc.annotations.Order;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 import java.util.Collection;
 import java.util.Collections;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Greeter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Greeter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Greeter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Greeter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public interface Greeter
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/GreeterModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/GreeterModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/GreeterModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/GreeterModule.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
-import org.apache.tapestry.ioc.annotation.Marker;
+import org.apache.tapestry5.ioc.annotations.InjectService;
+import org.apache.tapestry5.ioc.annotations.Marker;
 
 public class GreeterModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/HelterModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/HelterModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/HelterModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/HelterModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.SubModule;
+import org.apache.tapestry5.ioc.annotations.SubModule;
 
 
 @SubModule(SkelterModule.class)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Indirection.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Indirection.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Indirection.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Indirection.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Used to demonstrate indirection via symbols.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolder.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public interface IntHolder
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolderImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolderImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolderImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntHolderImpl.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class IntHolderImpl implements IntHolder
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntegrationTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntegrationTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntegrationTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/IntegrationTest.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.internal.ExceptionInConstructorModule;
-import org.apache.tapestry.ioc.internal.IOCInternalTestCase;
-import org.apache.tapestry.ioc.services.*;
+import org.apache.tapestry5.ioc.internal.ExceptionInConstructorModule;
+import org.apache.tapestry5.ioc.internal.IOCInternalTestCase;
+import org.apache.tapestry5.ioc.services.*;
 import org.easymock.EasyMock;
 import org.testng.Assert;
 import org.testng.annotations.Test;
@@ -456,7 +456,7 @@
         catch (RuntimeException ex)
         {
             assertMessageContains(ex,
-                                  "Class org.apache.tapestry.ioc.UnbuildablePingable does not contain a public constructor needed to autobuild.");
+                                  "Class org.apache.tapestry5.ioc.UnbuildablePingable does not contain a public constructor needed to autobuild.");
 
             // Like to check that the message includes the source location
 
@@ -480,7 +480,7 @@
         catch (RuntimeException ex)
         {
             assertMessageContains(ex,
-                                  "Class org.apache.tapestry.ioc.UnbuildablePingable does not contain a public constructor needed to autobuild.");
+                                  "Class org.apache.tapestry5.ioc.UnbuildablePingable does not contain a public constructor needed to autobuild.");
         }
 
         r.shutdown();
@@ -499,7 +499,7 @@
         }
         catch (RuntimeException ex)
         {
-            assertMessageContains(ex, "Error invoking constructor org.apache.tapestry.ioc.FailInConstructorRunnable()",
+            assertMessageContains(ex, "Error invoking constructor org.apache.tapestry5.ioc.FailInConstructorRunnable()",
                                   "Failure in Runnable constructor.");
 
             // Like to check that the message includes the source location
@@ -560,7 +560,7 @@
         catch (RuntimeException ex)
         {
             assertEquals(ex.getMessage(),
-                         "Service interface org.apache.tapestry.ioc.Pingable is matched by 2 services: Barney, Fred.  Automatic dependency resolution requires that exactly one service implement the interface.");
+                         "Service interface org.apache.tapestry5.ioc.Pingable is matched by 2 services: Barney, Fred.  Automatic dependency resolution requires that exactly one service implement the interface.");
         }
 
         r.shutdown();
@@ -592,7 +592,7 @@
         Greeter g = r.getService("Greeter", Greeter.class);
 
         assertEquals(g.getGreeting(), "Hello");
-        assertEquals(g.toString(), "<Proxy for Greeter(org.apache.tapestry.ioc.Greeter)>");
+        assertEquals(g.toString(), "<Proxy for Greeter(org.apache.tapestry5.ioc.Greeter)>");
 
         r.shutdown();
     }
@@ -605,7 +605,7 @@
         Greeter g = r.getService("${greeter}", Greeter.class);
 
         assertEquals(g.getGreeting(), "Hello");
-        assertEquals(g.toString(), "<Proxy for HelloGreeter(org.apache.tapestry.ioc.Greeter)>");
+        assertEquals(g.toString(), "<Proxy for HelloGreeter(org.apache.tapestry5.ioc.Greeter)>");
 
         r.shutdown();
     }
@@ -637,9 +637,9 @@
         catch (RuntimeException ex)
         {
             assertMessageContains(ex, "Error invoking service builder method",
-                                  "Unable to locate a single service assignable to type org.apache.tapestry.ioc.Greeter with marker annotation org.apache.tapestry.ioc.RedMarker",
-                                  "org.apache.tapestry.ioc.GreeterModule.buildRedGreeter1()",
-                                  "org.apache.tapestry.ioc.GreeterModule.buildRedGreeter2()");
+                                  "Unable to locate a single service assignable to type org.apache.tapestry5.ioc.Greeter with marker annotation org.apache.tapestry5.ioc.RedMarker",
+                                  "org.apache.tapestry5.ioc.GreeterModule.buildRedGreeter1()",
+                                  "org.apache.tapestry5.ioc.GreeterModule.buildRedGreeter2()");
         }
 
         r.shutdown();
@@ -660,7 +660,7 @@
         catch (RuntimeException ex)
         {
             assertMessageContains(ex, "Error invoking service builder method",
-                                  " Unable to locate any service assignable to type org.apache.tapestry.ioc.Greeter with marker annotation org.apache.tapestry.ioc.YellowMarker.");
+                                  " Unable to locate any service assignable to type org.apache.tapestry5.ioc.Greeter with marker annotation org.apache.tapestry5.ioc.YellowMarker.");
         }
 
         r.shutdown();
@@ -749,7 +749,7 @@
         assertEquals(CountingGreeterImpl.instantiationCount, 0);
 
         assertEquals(g.toString(),
-                     "<Autobuild proxy org.apache.tapestry.ioc.CountingGreeterImpl(org.apache.tapestry.ioc.Greeter)>");
+                     "<Autobuild proxy org.apache.tapestry5.ioc.CountingGreeterImpl(org.apache.tapestry5.ioc.Greeter)>");
 
         assertEquals(CountingGreeterImpl.instantiationCount, 0);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MarkerModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MarkerModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MarkerModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MarkerModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Marker;
+import org.apache.tapestry5.ioc.annotations.Marker;
 
 public class MarkerModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MasterModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MasterModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NameListHolder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NameListHolder.java Tue May 20 11:51:35 2008
@@ -1,25 +1,25 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 import java.util.List;
 
 /**
- * Used for testing of ordered and unordered contributions. The names are contributed in from
- * multiple modules. For unordered contributions, the values are sorted alphabetically. For ordered
- * contributions, the values are ordered as per the contributions.
+ * Used for testing of ordered and unordered contributions. The names are contributed in from multiple modules. For
+ * unordered contributions, the values are sorted alphabetically. For ordered contributions, the values are ordered as
+ * per the contributions.
  */
 public interface NameListHolder
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NonProxiedServiceModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NonProxiedServiceModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NonProxiedServiceModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NonProxiedServiceModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class NonProxiedServiceModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/PerThreadModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/PerThreadModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/PerThreadModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/PerThreadModule.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import static org.apache.tapestry.ioc.IOCConstants.PERTHREAD_SCOPE;
-import org.apache.tapestry.ioc.annotation.Scope;
+import static org.apache.tapestry5.ioc.IOCConstants.PERTHREAD_SCOPE;
+import org.apache.tapestry5.ioc.annotations.Scope;
 
 public class PerThreadModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Pingable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Pingable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Pingable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Pingable.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Interface used as a stand-in for testing for more complicated services.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RecursiveConstructorModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RecursiveConstructorModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedGreeterImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedGreeterImpl.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Marker;
+import org.apache.tapestry5.ioc.annotations.Marker;
 
 @Marker(RedMarker.class)
 public class RedGreeterImpl implements Greeter

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedMarker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedMarker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedMarker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedMarker.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,7 +22,7 @@
 import java.lang.annotation.Target;
 
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface RedMarker

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTest.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import org.testng.annotations.Test;
 
 import java.util.Arrays;
@@ -62,7 +62,7 @@
         // This proves that the IOC works, the service builder method was invoked, that the
         // ClassFactory service was accessed and used.
 
-        assertEquals(service.toString(), "<Proxy for Square(org.apache.tapestry.ioc.Square)>");
+        assertEquals(service.toString(), "<Proxy for Square(org.apache.tapestry5.ioc.Square)>");
 
         registry.shutdown();
     }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTestModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTestModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTestModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RegistryBuilderTestModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class RegistryBuilderTestModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ServiceBuilderAutobuilderModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ServiceBuilderAutobuilderModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ServiceBuilderAutobuilderModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/ServiceBuilderAutobuilderModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class ServiceBuilderAutobuilderModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Sizer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Sizer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Sizer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Sizer.java Tue May 20 11:51:35 2008
@@ -1,22 +1,22 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * Encapsulates a strategy for determining the size of an object. Different implementations are
- * mapped to different types.
+ * Encapsulates a strategy for determining the size of an object. Different implementations are mapped to different
+ * types.
  */
 public interface Sizer
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/SkelterModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/SkelterModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/SkelterModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/SkelterModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.SubModule;
+import org.apache.tapestry5.ioc.annotations.SubModule;
 
 @SubModule(HelterModule.class)
 public class SkelterModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Square.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Square.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StaticModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StaticModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 import java.util.Collection;
 import java.util.Collections;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolder.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolderImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolderImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolderImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringHolderImpl.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringTransformer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringTransformer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnbuildablePingable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnbuildablePingable.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Used to test failure to autobuild a service because of a lack of a public constructor.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownColorGreeterImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownColorGreeterImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownColorGreeterImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownColorGreeterImpl.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class UnknownColorGreeterImpl implements Greeter
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownScopeModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownScopeModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownScopeModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnknownScopeModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Scope;
+import org.apache.tapestry5.ioc.annotations.Scope;
 
 public class UnknownScopeModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/YellowMarker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/YellowMarker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/YellowMarker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/YellowMarker.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,7 +22,7 @@
 import java.lang.annotation.Target;
 
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface YellowMarker

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ArrayDecoratorMethodModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ArrayDecoratorMethodModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/BuilderMethodModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/BuilderMethodModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 public class BuilderMethodModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ComplexAutobuildModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ComplexAutobuildModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ComplexAutobuildModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ComplexAutobuildModule.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBinder;
-import org.apache.tapestry.ioc.StringHolder;
-import org.apache.tapestry.ioc.StringHolderImpl;
+import org.apache.tapestry5.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.StringHolder;
+import org.apache.tapestry5.ioc.StringHolderImpl;
 
 public class ComplexAutobuildModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ContributionDefImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ContributionDefImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ContributionDefImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ContributionDefImplTest.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.InjectService;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.InjectService;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import static org.easymock.EasyMock.eq;
 import static org.easymock.EasyMock.isA;
 import org.testng.annotations.Test;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultModuleDefImplTest.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.def.ContributionDef;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import static org.apache.tapestry.ioc.internal.IOCMessages.buildMethodConflict;
-import org.apache.tapestry.ioc.internal.services.ClassFactoryImpl;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.ClassFactory;
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.def.ContributionDef;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import static org.apache.tapestry5.ioc.internal.IOCMessages.buildMethodConflict;
+import org.apache.tapestry5.ioc.internal.services.ClassFactoryImpl;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import static org.easymock.EasyMock.and;
 import static org.easymock.EasyMock.contains;
 import org.slf4j.Logger;
@@ -385,7 +385,7 @@
         catch (RuntimeException ex)
         {
             assertEquals(ex.getMessage(),
-                         "Class org.apache.tapestry.ioc.internal.RunnableServiceImpl (implementation of service \'Runnable\') does not contain any public constructors.");
+                         "Class org.apache.tapestry5.ioc.internal.RunnableServiceImpl (implementation of service \'Runnable\') does not contain any public constructors.");
         }
 
         verify();
@@ -421,7 +421,7 @@
 
         logger
                 .debug(contains(
-                        "Invoking constructor org.apache.tapestry.ioc.internal.MultipleConstructorsAutobuildService(StringHolder)"));
+                        "Invoking constructor org.apache.tapestry5.ioc.internal.MultipleConstructorsAutobuildService(StringHolder)"));
 
         train_getServiceId(resources, "StringHolder");
         train_getLogger(resources, logger);
@@ -464,7 +464,7 @@
             assertTrue(ex
                     .getMessage()
                     .matches(
-                    "Error invoking service binder method org.apache.tapestry.ioc.internal.ExceptionInBindMethod.bind\\(ServiceBinder\\) " + "\\(at ExceptionInBindMethod.java:\\d+\\): Really, how often is this going to happen\\?"));
+                    "Error invoking service binder method org.apache.tapestry5.ioc.internal.ExceptionInBindMethod.bind\\(ServiceBinder\\) " + "\\(at ExceptionInBindMethod.java:\\d+\\): Really, how often is this going to happen\\?"));
         }
 
         verify();

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultServiceIdModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultServiceIdModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultServiceIdModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/DefaultServiceIdModule.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 public class DefaultServiceIdModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 public class EagerLoadViaAnnotationModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationServiceImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationServiceImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationServiceImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/EagerLoadViaAnnotationServiceImpl.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.annotation.EagerLoad;
+import org.apache.tapestry5.ioc.annotations.EagerLoad;
 
 @EagerLoad
 public class EagerLoadViaAnnotationServiceImpl implements Runnable

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInBindMethod.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInBindMethod.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInBindMethod.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInBindMethod.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 public class ExceptionInBindMethod
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorModule.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.Pingable;
-import org.apache.tapestry.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.Pingable;
+import org.apache.tapestry5.ioc.ServiceBinder;
 
 public class ExceptionInConstructorModule
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorServiceImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorServiceImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorServiceImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExceptionInConstructorServiceImpl.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.Pingable;
+import org.apache.tapestry5.ioc.Pingable;
 
 public class ExceptionInConstructorServiceImpl implements Pingable
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExtraPublicConstructorsModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExtraPublicConstructorsModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FieService.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FieService.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * A placeholder for a real service interface.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FoeService.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FoeService.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FoeService.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FoeService.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * A placeholder for a real service interface.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcherTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcherTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcherTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/GlobPatternMatcherTest.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertTrue;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilderTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilderTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilderTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/InterceptorStackBuilderTest.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import org.apache.tapestry.ioc.ServiceDecorator;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import org.apache.tapestry5.ioc.ServiceDecorator;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
 import org.testng.annotations.Test;
 
 import static java.util.Arrays.asList;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/LoggerSourceImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/LoggerSourceImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/LoggerSourceImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/LoggerSourceImplTest.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.LoggerSource;
+import org.apache.tapestry5.ioc.LoggerSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testng.annotations.Test;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MappedConfigurationModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MappedConfigurationModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTest.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.RegistryBuilder;
-import org.apache.tapestry.ioc.def.DecoratorDef;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.def.ServiceDef;
-import org.apache.tapestry.ioc.internal.services.ClassFactoryImpl;
-import org.apache.tapestry.ioc.services.ClassFactory;
-import org.apache.tapestry.ioc.services.RegistryShutdownListener;
-import org.apache.tapestry.ioc.services.Status;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.RegistryBuilder;
+import org.apache.tapestry5.ioc.def.DecoratorDef;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.internal.services.ClassFactoryImpl;
+import org.apache.tapestry5.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.services.RegistryShutdownListener;
+import org.apache.tapestry5.ioc.services.Status;
 import static org.easymock.EasyMock.contains;
 import static org.easymock.EasyMock.isA;
 import org.slf4j.Logger;
@@ -155,7 +155,7 @@
         catch (RuntimeException ex)
         {
             assertEquals(ex.getMessage(),
-                         "Module builder class org.apache.tapestry.ioc.internal.PrivateConstructorModule " + "does not contain any public constructors.");
+                         "Module builder class org.apache.tapestry5.ioc.internal.PrivateConstructorModule " + "does not contain any public constructors.");
         }
 
         verify();
@@ -209,7 +209,7 @@
         UpcaseService us = registry.getService(UpcaseService.class);
 
         assertEquals(us.upcase("hello"), "HELLO");
-        assertEquals(us.toString(), "<Proxy for Upcase(org.apache.tapestry.ioc.internal.UpcaseService)>");
+        assertEquals(us.toString(), "<Proxy for Upcase(org.apache.tapestry5.ioc.internal.UpcaseService)>");
 
         ToStringService ts = registry.getService(ToStringService.class);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTestModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTestModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTestModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTestModule.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
+import org.apache.tapestry5.ioc.annotations.InjectService;
 
 /**
  * Module builder used by {@link ModuleImplTest}.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MultipleConstructorsAutobuildService.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MultipleConstructorsAutobuildService.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MultipleConstructorsAutobuildService.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MultipleConstructorsAutobuildService.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.StringHolder;
-import org.apache.tapestry.ioc.annotation.InjectService;
+import org.apache.tapestry5.ioc.StringHolder;
+import org.apache.tapestry5.ioc.annotations.InjectService;
 
 public class MultipleConstructorsAutobuildService implements StringHolder
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MutlipleAutobuildServiceConstructorsModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MutlipleAutobuildServiceConstructorsModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MutlipleAutobuildServiceConstructorsModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MutlipleAutobuildServiceConstructorsModule.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.ServiceBinder;
-import org.apache.tapestry.ioc.StringHolder;
+import org.apache.tapestry5.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.StringHolder;
 
 public class MutlipleAutobuildServiceConstructorsModule
 {
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MasterModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/MasterModule.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.SubModule;
+import org.apache.tapestry5.ioc.annotations.SubModule;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.RegistryBuilderTest}.
  */
 @SubModule(
         { FredModule.class, BarneyModule.class })
@@ -12,12 +12,12 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.RegistryBuilderTest}.
+ * Used by {@link org.apache.tapestry5.ioc.RegistryBuilderTest}.
  */
 @SubModule(

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NameListHolder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/NameListHolder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RecursiveConstructorModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RecursiveConstructorModule.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
+import org.apache.tapestry5.ioc.annotations.InjectService;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.IntegrationTest}.
  */
 public class RecursiveConstructorModule
 {
@@ -12,12 +12,12 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.IntegrationTest}.
+ * Used by {@link org.apache.tapestry5.ioc.IntegrationTest}.
  */
 public class RecursiveConstructorModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedGreeterImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/RedGreeterImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Square.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/Square.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.RegistryBuilderTest}.
  */
 public interface Square
 {
@@ -12,10 +12,10 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.RegistryBuilderTest}.
+ * Used by {@link org.apache.tapestry5.ioc.RegistryBuilderTest}.
  */
 public interface Square

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StaticModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StaticModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringTransformer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/StringTransformer.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.IntegrationTest}.
  */
 public interface StringTransformer
 {
@@ -12,10 +12,10 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.IntegrationTest}.
+ * Used by {@link org.apache.tapestry5.ioc.IntegrationTest}.
  */
 public interface StringTransformer

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnbuildablePingable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/UnbuildablePingable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ArrayDecoratorMethodModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ArrayDecoratorMethodModule.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImplTest}.
  */
 public class ArrayDecoratorMethodModule
 {
@@ -12,10 +12,10 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImplTest}.
+ * Used by {@link org.apache.tapestry5.ioc.internal.DefaultModuleDefImplTest}.
  */
 public class ArrayDecoratorMethodModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/BuilderMethodModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/BuilderMethodModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExtraPublicConstructorsModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ExtraPublicConstructorsModule.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.annotation.InjectService;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.annotations.InjectService;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.internal.ModuleImplTest}.
  */
 public class ExtraPublicConstructorsModule
 {
@@ -12,13 +12,13 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.internal.ModuleImplTest}.
+ * Used by {@link org.apache.tapestry5.ioc.internal.ModuleImplTest}.
  */
 public class ExtraPublicConstructorsModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FieService.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/FieService.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MappedConfigurationModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/MappedConfigurationModule.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
-import org.apache.tapestry.ioc.MappedConfiguration;
+import org.apache.tapestry5.ioc.MappedConfiguration;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImpl}.
  */
 public class MappedConfigurationModule
 {
@@ -12,12 +12,12 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImpl}.
+ * Used by {@link org.apache.tapestry5.ioc.internal.DefaultModuleDefImpl}.
  */
 public class MappedConfigurationModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleBuilderWithId.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleBuilderWithId.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleBuilderWithId.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleBuilderWithId.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal;
+package org.apache.tapestry5.ioc.internal;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImplTest}.
  */
 public class ModuleBuilderWithId
 {
@@ -12,10 +12,10 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.internal.DefaultModuleDefImplTest}.
+ * Used by {@link org.apache.tapestry5.ioc.internal.DefaultModuleDefImplTest}.
  */
 public class ModuleBuilderWithId

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/test/java/org/apache/tapestry5/ioc/internal/ModuleImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================